import pandas as pd 
import requests 
import os
import re
import tqdm 

##################################################################################################################
# Only edit these two variables. Leave anything else untouched.
# Download the data from the old Toon using the standard functionality. This will give you a file export.zip
# Enery consumption files are located in the file usage.zip inside export.zip. 
# extract all csv files from usage.zip into a separate folder.
# folderPath should contains the location of the extracted csv files
# tooIpAddress should contains the ipAddress of the target Toon
##################################################################################################################
folderPath = "c:\\temp\\usage\\"
toonIpAddress = "192.168.2.16"

##################################################################################################################
# DO NOT CHANGE ANYTHING BELOW THIS LINE
##################################################################################################################

# function which does the actual work by sending the values from the csv files to the target Toon

def loadInput(ipAddress, loggerName, filename, rra):

    # empty files give an error, need to skip those (e.g. district heating data)

    try:
        df = pd.read_csv(filename, header=None)
        df.columns=["time","value"]
    except:
        print("failed (empty?) to load:", filename)
        return

    # send an http request for each line item

    url = 'http://' + ipAddress + '/hcb_rrd?action=setRrdData&loggerName=' + loggerName + '&rra=' + rra + '&samples={{"{}":{}}}'
    for t, v in tqdm.tqdm(zip(list(df["time"]), list(df["value"])), total=len(list(df["value"]))):
        try:
            r = requests.get(url.format(t,v))
        except requests.exceptions.ConnectionError as e:
            try:
                # retry once, sometimes connection is refused by host
                r = requests.get(url.format(t,v))
            except:        
                print("\nerror:" + url.format(t,v))

# Main routine

files = [x for x in os.listdir(folderPath) if x[-4:] == ".csv"]
rraNames = [x[:-4].split("_")[-1] for x in files]
loggerNames = [x[re.search("[a-z_]+[A-Z]", x).start():re.search("[a-z_]+[A-Z]", x).end()][:-2] for x in files]

for i in range(len(files)):
    print(files[i])
    loadInput(toonIpAddress, loggerNames[i], folderPath + files[i], rraNames[i])
